==> ah-form-builder-sample-0.6.19.tgz: package/es/components/toolbar/App.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/toolbar/App.js";

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import Drawer from "./Drawer";
import Typography from '@material-ui/core/Typography';
import ListItem from '@material-ui/core/ListItem';
import Icon from './icons';
import config from '../../config';
import './styles.scss';
import { generateSampleData } from "../../utils/helpers";
import { connect } from "react-redux";
import { enableFieldEdit as _enableFieldEdit } from "../../actions/toolbarActions";
import { createField as _createField, setOrder as _setOrder } from '../../actions/formActions';
import EditField from "./EditField";
var fields = [{
  label: 'Text Field',
  slug: 'text',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "text",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 15,
      columnNumber: 47
    }
  })
}, {
  label: 'Select / Dropdown',
  slug: 'select',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "select",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 16,
      columnNumber: 56
    }
  })
}, {
  label: 'Checkbox Group',
  slug: 'checkbox',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "checkbox",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 17,
      columnNumber: 55
    }
  })
}, {
  label: 'Radio Group',
  slug: 'radio',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "checkbox",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 18,
      columnNumber: 49
    }
  })
}, {
  label: 'Date Field',
  slug: 'date',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "date",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 19,
      columnNumber: 47
    }
  })
}, {
  label: 'Content',
  slug: 'content',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "content",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 20,
      columnNumber: 47
    }
  })
}, {
  label: 'File Upload',
  slug: 'file',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "file-upload",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 21,
      columnNumber: 48
    }
  })
}, {
  label: 'Quiz',
  slug: 'quiz',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "quiz",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 22,
      columnNumber: 41
    }
  })
}, {
  label: 'Survey',
  slug: 'survey',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "survey",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 23,
      columnNumber: 45
    }
  })
}, {
  label: 'List',
  slug: 'list',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "list",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 24,
      columnNumber: 41
    }
  })
}, {
  label: 'E-Signature',
  slug: 'signature',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "signature",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 25,
      columnNumber: 53
    }
  })
}, {
  label: 'Image',
  slug: 'image',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "image",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 26,
      columnNumber: 43
    }
  })
}, {
  label: 'Video',
  slug: 'video',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "video",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 27,
      columnNumber: 43
    }
  })
}, {
  label: 'Section',
  slug: 'section',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "section",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 28,
      columnNumber: 47
    }
  })
}];

var App = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(App, _React$Component);

  function App() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "addNewField", function (slug) {
      var data = generateSampleData(slug, _this.props.order);

      _this.props.createField(data);
    });

    _defineProperty(_assertThisInitialized(_this), "onDragStart", function (e, slug) {
      e.dataTransfer.setData("droppedFieldSlug", slug);
    });

    _defineProperty(_assertThisInitialized(_this), "onDragEnd", function (e) {
      e.dataTransfer.setData("droppedFieldSlug", null);
    });

    _defineProperty(_assertThisInitialized(_this), "renderFieldItems", function () {
      var count = -1;
      return fields.map(function (field, index) {
        if (config.hiddenFields.indexOf(field.slug) === -1) {
          count++;
          return /*#__PURE__*/React.createElement("div", {
            className: count % 2 === 0 ? "col-md-6 pt-3 disable-highlight pr-1" : "col-md-6 pt-3 disable-highlight pl-1",
            key: 'field-' + field.slug,
            onDragStart: function onDragStart(e) {
              return _this.onDragStart(e, field.slug);
            },
            onDragOver: function onDragOver(e) {
              return e.preventDefault();
            },
            onDragEnd: function onDragEnd(e) {
              return _this.onDragEnd(e);
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 50,
              columnNumber: 13
            }
          }, /*#__PURE__*/React.createElement(ListItem, {
            button: true,
            className: "p-0",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 55,
              columnNumber: 15
            }
          }, /*#__PURE__*/React.createElement("div", {
            className: "field-type-container pt-3 cursor-pointer",
            onDoubleClick: function onDoubleClick(e) {
              return _this.addNewField(field.slug);
            },
            draggable: "true",
            onDragStart: function onDragStart(e) {
              return _this.onDragStart(e, field.slug);
            },
            onDragOver: function onDragOver(e) {
              return e.preventDefault();
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 56,
              columnNumber: 15
            }
          }, field.icon, /*#__PURE__*/React.createElement(Typography, {
            variant: "subtitle1",
            gutterBottom: true,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 62,
              columnNumber: 17
            }
          }, field.label))));
        }

        return '';
      });
    });

    return _this;
  }

  var _proto = App.prototype;

  _proto.render = function render() {
    if (this.props.editId || this.props.newFieldData) {
      return /*#__PURE__*/React.createElement("div", {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 79,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(Drawer, {
        title: "Question Types",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 80,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "row m-0",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 81,
          columnNumber: 13
        }
      }, /*#__PURE__*/React.createElement(EditField, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 82,
          columnNumber: 15
        }
      }))));
    }

    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 89,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Drawer, {
      title: "Question Types",
      type: "fields",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 90,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "row m-0",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 91,
        columnNumber: 11
      }
    }, this.renderFieldItems())));
  };

  return App;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    newFieldData: state.form.newFieldData,
    editId: state.toolbar.editId,
    data: state.form.data,
    order: state.form.order
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    enableFieldEdit: function enableFieldEdit(id, operation) {
      return dispatch(_enableFieldEdit(id, operation));
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    setOrder: function setOrder(data) {
      return dispatch(_setOrder(data));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(App);

==> ah-form-builder-sample-0.6.85.tgz: package/es/components/toolbar/App.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/toolbar/App.js";

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import Drawer from "./Drawer";
import Typography from '@material-ui/core/Typography';
import ListItem from '@material-ui/core/ListItem';
import Icon from './icons';
import config from '../../config';
import './styles.scss';
import { generateSampleData } from "../../utils/helpers";
import { connect } from "react-redux";
import { enableFieldEdit as _enableFieldEdit } from "../../actions/toolbarActions";
import { createField as _createField, setOrder as _setOrder } from '../../actions/formActions';
import EditField from "./EditField";
import { Grid } from '@material-ui/core';
var titleLabel = {
  en: 'Question Types',
  ar: 'أنواع الأسئلة'
};
var fields = [{
  label: {
    en: 'Text Field',
    ar: 'حقل نصّي'
  },
  slug: 'text',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "text",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 21,
      columnNumber: 71
    }
  })
}, {
  label: {
    en: 'Select / Dropdown',
    ar: 'حدد / منسدلة'
  },
  slug: 'select',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "select",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 22,
      columnNumber: 84
    }
  })
}, {
  label: {
    en: 'Checkbox Group',
    ar: 'مجموعة خانات الاختيار'
  },
  slug: 'checkbox',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "checkbox",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 23,
      columnNumber: 92
    }
  })
}, {
  label: {
    en: 'Radio Group',
    ar: 'مجموعة راديو'
  },
  slug: 'radio',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "checkbox",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 24,
      columnNumber: 77
    }
  })
}, {
  label: {
    en: 'Date Field',
    ar: 'حقل التاريخ'
  },
  slug: 'date',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "date",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 25,
      columnNumber: 74
    }
  })
}, {
  label: {
    en: 'Content',
    ar: 'المحتوى'
  },
  slug: 'content',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "content",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 26,
      columnNumber: 70
    }
  })
}, {
  label: {
    en: 'File Upload',
    ar: 'تحميل الملف'
  },
  slug: 'file',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "file-upload",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 27,
      columnNumber: 75
    }
  })
}, {
  label: {
    en: 'Quiz',
    ar: 'Quiz'
  },
  slug: 'quiz',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "quiz",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 28,
      columnNumber: 61
    }
  })
}, {
  label: {
    en: 'Survey',
    ar: 'Survey'
  },
  slug: 'survey',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "survey",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 29,
      columnNumber: 67
    }
  })
}, {
  label: {
    en: 'List',
    ar: 'List'
  },
  slug: 'list',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "list",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 30,
      columnNumber: 61
    }
  })
}, {
  label: {
    en: 'E-Signature',
    ar: 'التوقيع الإلكتروني'
  },
  slug: 'signature',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "signature",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 31,
      columnNumber: 87
    }
  })
}, {
  label: {
    en: 'Image',
    ar: 'صورة'
  },
  slug: 'image',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "image",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 32,
      columnNumber: 63
    }
  })
}, {
  label: {
    en: 'Video',
    ar: 'فيديو'
  },
  slug: 'video',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "video",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 33,
      columnNumber: 64
    }
  })
}, {
  label: {
    en: 'Section',
    ar: 'Section'
  },
  slug: 'section',
  'icon': /*#__PURE__*/React.createElement(Icon, {
    name: "section",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 34,
      columnNumber: 70
    }
  })
}];

var App = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(App, _React$Component);

  function App() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "addNewField", function (slug) {
      var data = generateSampleData(slug, _this.props.order);

      _this.props.createField(data);
    });

    _defineProperty(_assertThisInitialized(_this), "onDragStart", function (e, slug) {
      e.dataTransfer.setData("droppedFieldSlug", slug);
    });

    _defineProperty(_assertThisInitialized(_this), "onDragEnd", function (e) {
      e.dataTransfer.setData("droppedFieldSlug", null);
    });

    _defineProperty(_assertThisInitialized(_this), "renderFieldItems", function () {
      var count = -1;
      return fields.map(function (field, index) {
        if (config.hiddenFields.indexOf(field.slug) === -1) {
          count++;
          return /*#__PURE__*/React.createElement(Grid, {
            item: true,
            md: 6,
            xs: 12,
            className: count % 2 === 0 ? "ahfb-pt-3 ahfb-pr-1" : "ahfb-pt-3 ahfb-pl-1",
            key: 'field-' + field.slug,
            onDragStart: function onDragStart(e) {
              return _this.onDragStart(e, field.slug);
            },
            onDragOver: function onDragOver(e) {
              return e.preventDefault();
            },
            onDragEnd: function onDragEnd(e) {
              return _this.onDragEnd(e);
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 56,
              columnNumber: 13
            }
          }, /*#__PURE__*/React.createElement(ListItem, {
            button: true,
            className: "ahfb-p-0",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 61,
              columnNumber: 15
            }
          }, /*#__PURE__*/React.createElement("div", {
            className: "ahfb-field-type-container ahfb-pt-3 ahfb-cursor-pointer",
            onDoubleClick: function onDoubleClick(e) {
              return _this.addNewField(field.slug);
            },
            draggable: "true",
            onDragStart: function onDragStart(e) {
              return _this.onDragStart(e, field.slug);
            },
            onDragOver: function onDragOver(e) {
              return e.preventDefault();
            },
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 62,
              columnNumber: 17
            }
          }, field.icon, /*#__PURE__*/React.createElement(Typography, {
            variant: "subtitle1",
            gutterBottom: true,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 68,
              columnNumber: 19
            }
          }, field.label[_this.props.currentLang]))));
        }

        return '';
      });
    });

    return _this;
  }

  var _proto = App.prototype;

  _proto.render = function render() {
    if (this.props.editId || this.props.newFieldData) {
      return /*#__PURE__*/React.createElement("div", {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 84,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement(Drawer, {
        title: titleLabel[this.props.currentLang],
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 85,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement("div", {
        className: "ahfb-m-0",
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 86,
          columnNumber: 13
        }
      }, /*#__PURE__*/React.createElement(EditField, {
        __self: this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 87,
          columnNumber: 15
        }
      }))));
    }

    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 94,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(Drawer, {
      title: titleLabel[this.props.currentLang],
      type: "fields",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 95,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement(Grid, {
      container: true,
      className: "ahfb-p-2",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 96,
        columnNumber: 11
      }
    }, this.renderFieldItems())));
  };

  return App;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    newFieldData: state.form.newFieldData,
    editId: state.toolbar.editId,
    data: state.form.data,
    order: state.form.order,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    enableFieldEdit: function enableFieldEdit(id, operation) {
      return dispatch(_enableFieldEdit(id, operation));
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    setOrder: function setOrder(data) {
      return dispatch(_setOrder(data));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(App);
